package models

data class CountryAVS(
	var id: String?,
	var name: String?,
)

data class IdentifierDocumentAVS(
	var number: String,
	var series: String?,
	var type: DocTypeAVS,
)

data class SessionAVS(
	var id: String,
)

data class RegionAVS(
	var name: String?,
	var type: String?,
	var country: CountryAVS?,
	var id: String?,
)

data class Settings(
	var defaultPlaceId: String,
	var defaultStationId: String,
)

data class AreaAVS(
	var name: String?,
	var type: String?,
	var id: String?,
)

data class AuthRequest(
	var username: String,
	var password: String,
	var ws: String,
)

data class PassengerAVS(
	var passenger: PassengerPartPassengerAVS,
	var identifierDocument: IdentifierDocumentAVS,
	var benefitDocument: BenefitDocumentAVS?,
	var categoryId: Int,
)

data class PassengerPartPassengerAVS(
	var citizenship: CitizenshipAVS,
	var docNum: String?,
	var docSeries: String?,
	var docTypeId: String?,
	var gender: String,
	var birthDate: String?,
	var id: Int?,
	var lastName: String,
	var middleName: String?,
	var phone: String?,
	var firstName: String,
)

data class TicketCategoryAVS(
	var requiredDocTypes: List<DocumentTypeAVS>?,
	var id: String,
	var name: String,
	var price: Double,
)

data class TicketTypeAVS(
	var id: String,
	var name: String,
	var requiredDocTypes: List<RequiredDocTypeAVS>?,
)

data class PlaceAVS(
	var region: RegionAVS?,
	var area: AreaAVS?,
	var id: String?,
	var name: String?,
	var type: String?,
)

data class StationAVS(
	var id: String?,
	var name: String?,
	var shortName: String?,
	var address: String?,
)

data class BusSeatAVS(
	var id: String,
	var name: String,
	var num: Int,
)

data class DeparturesKassa(
	var arrivals: List<ArrivalsAVS>,
	var place: PlaceAVS?,
	var station: StationAVS?,
	var time: String?,
	var tripId: String?,
	var priceText: String,
)

data class DocTypeAVS(
	var id: String,
	var name: String,
)

data class AuthDTO(
	var token: String?,
	var refreshToken: String?,
	var expireAt: Int?,
)

data class OrderAVS(
	var orderId: Int,
	var tickets: List<TicketAVS>,
	var expirationTime: String?,
	var confirmError: String?,
)

data class CitizenshipAVS(
	var id: String,
	var name: String,
)

data class CountryCode(
	var name: String,
	var code: String,
)

data class RequiredDocTypeAVS(
	var id: String,
	var name: String,
)

data class TicketAVS(
	var category: TicketCategoryAVS?,
	var number: String?,
	var passenger: PassengerPartPassengerAVS?,
	var seat: BusSeatAVS?,
	var series: String?,
	var ticketClass: String,
	var benefitDocument: BenefitDocumentAVS?,
	var id: String,
	var identifierDocument: IdentifierDocumentAVS?,
	var payments: List<TicketPaymentAVS>?,
	var status: String,
)

data class TripKassa(
	var bus: BusAVS?,
	var seatsText: String,
	var carrier: CarrierAVS?,
	var changeSeatAllow: Boolean?,
	var departures: List<DeparturesKassa>,
	var name: String?,
)

data class BenefitDocumentAVS(
	var issuer: String?,
	var number: String,
	var series: String?,
	var type: DocTypeAVS,
	var beginDate: String?,
	var endDate: String?,
	var issueDate: String?,
)

data class BusAVS(
	var capacity: Int?,
	var freeSeats: Int?,
	var info: String?,
)

data class CarrierAVS(
	var inn: String?,
	var name: String?,
)

data class ArrivalsAVS(
	var price: Int?,
	var station: StationAVS?,
	var time: String?,
)

data class DocumentTypeAVS(
	var id: String,
	var name: String,
)

data class TicketPaymentAVS(
	var amount: Double,
	var from: String?,
	var group: String,
	var id: String,
	var name: String,
	var nds: String,
)

